﻿// ----------------------------------------------------------------------------------
// Sample Code from Fernando Machado Píriz's blog: http://fernandomachadopiriz.com
//
// <copyright company="Fernando Machado Píriz" file="DesktopBackgroundPart.cs">
// Copyright (c) Fernando Machado Píriz. Distributed under FSF's GPL v2.</copyright>
// ----------------------------------------------------------------------------------
// This code and information are provided "as is" without warranty of any kind,
// either expressed of implied, including but not limited to the implied warranties
// of merchantability and/or fitness for a particular purpose.
// ----------------------------------------------------------------------------------
namespace DesktopBackground
{
    using System.ComponentModel.Composition;
    using System.Windows;
    using System.Windows.Input;
    using GivingAPresentation.Commons;
    
    /// <summary>
    /// An extension part to replace or remove desktop background while the user is delivering a presentation.
    /// </summary>
    [Export(typeof(IContract))]
    [ExportMetadata("Tab", "")]
    public class DesktopBackgroundPart : IContract
    {
        /// <summary>
        /// The view of this extension part in the Model View View Model pattern.
        /// </summary>
        private DesktopBackgroundView desktopBackgroundView;

        /// <summary>
        /// The view model of this extension part in the Model View View Model pattern.
        /// </summary>
        private DesktopBackgroundViewModel desktopBackgroundViewModel;

        /// <summary>
        /// The model of this extension part in the Model View View Model pattern.
        /// </summary>        
        private DesktopBackgroundModel desktopBackgroundModel;

        /// <summary>
        /// Initializes a new instance of the DesktopBackgroundPart class.
        /// </summary>
        public DesktopBackgroundPart()
        {
            this.desktopBackgroundView = new DesktopBackgroundView();
            this.desktopBackgroundViewModel = this.desktopBackgroundView.Resources["desktopBackgroundViewModel"] as DesktopBackgroundViewModel;
            this.desktopBackgroundModel = this.desktopBackgroundViewModel.Model;

            this.StartPresentation = new RelayCommand(
                argument => this.desktopBackgroundViewModel.DoStartPresentation(),
                result => !this.desktopBackgroundModel.Presenting);

            this.StopPresentation = new RelayCommand(
                argument => this.desktopBackgroundViewModel.DoStopPresentation(),
                result => this.desktopBackgroundModel.Presenting);

            this.InitializePart = new RelayCommand(
                settingsManager => this.desktopBackgroundViewModel.DoInitializePart(),
                result => !this.desktopBackgroundModel.Presenting);

            this.FinalizePart = new RelayCommand(
                settingsManager => this.desktopBackgroundViewModel.DoFinalizePart(),
                result => !this.desktopBackgroundModel.Presenting);
        }

        #region IContract Members

        /// <summary>
        /// Gets the user control of this extension part.
        /// </summary>
        public FrameworkElement Element
        {
            get
            {
                return this.desktopBackgroundView;
            }
        }

        /// <summary>
        /// Gets the command used to notify component parts to apply changes when the user is starting a presentation. This command has no
        /// arguments.
        /// </summary>
        public ICommand StartPresentation { get; private set; }

        /// <summary>
        /// Gets the command used notify component parts to undo changes when the user ends giving a presentation. This command has no
        /// arguments.
        /// </summary>
        public ICommand StopPresentation { get; private set; }

        /// <summary>
        /// Gets the command used to notify component parts before they are used for the first time. Parts should load previously stored state.
        /// This command receives an <code>ISettingsManager</code> instance as settingsManager.
        /// </summary>
        public ICommand InitializePart { get; private set; }

        /// <summary>
        /// Gets the command used notify component parts when they are not needed anymore. Parts should store currently configured state. This
        /// command receives an <code>ISettingsManager</code> instance as settingsManager.
        /// </summary>
        public ICommand FinalizePart { get; private set; }

        #endregion // IContract Members
    }
}
