﻿// ----------------------------------------------------------------------------------
// Sample Code from Fernando Machado Píriz's blog: http://fernandomachadopiriz.com
//
// <copyright company="Fernando Machado Píriz" file="DesktopIconsModel.cs">
// Copyright (c) Fernando Machado Píriz. Distributed under FSF's GPL v2.</copyright>
// ----------------------------------------------------------------------------------
// This code and information are provided "as is" without warranty of any kind,
// either expressed of implied, including but not limited to the implied warranties
// of merchantability and/or fitness for a particular purpose.
// ----------------------------------------------------------------------------------
namespace DesktopIcons
{
    using System;
    using System.ComponentModel;
    using System.Diagnostics;
    using System.Reflection;
    using GivingAPresentation.Commons;
    
    /// <summary>
    /// The model of the <code>DesktopIconsView</code> using the Model View View Model pattern.
    /// </summary>
    public class DesktopIconsModel : BaseModel
    {
        /// <summary>
        /// The name of the setting exposed in this user control.
        /// </summary>
        private const string HideDesktopIconsSettingName = "HideDesktopIcons";

        /// <summary>
        /// The backend field for the <code>Remove</code> property.
        /// </summary>
        private bool hide;

        /// <summary>
        /// Gets or sets a value indicating whether the desktop background should be hided while the user is giving a presentation.
        /// </summary>
        public bool Hide
        {
            get
            {
                return this.hide;
            }

            set
            {
                this.hide = value;
                this.NotifyPropertyChanged("Hide");
            }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the user is giving a presentation.
        /// </summary>
        public bool Presenting { get; set; }

        /// <summary>
        /// Load model state using the <code>SettingsManager</code>.
        /// </summary>
        public void Load()
        {
            this.Hide = SettingsManager.Instance.GetValue(HideDesktopIconsSettingName, true);
        }

        /// <summary>
        /// Saves model state using the <code>SettingsManager</code>.
        /// </summary>
        public void Save()
        {
            SettingsManager.Instance.SetValue(HideDesktopIconsSettingName, this.Hide);
        }
    }
}
